==> react-atom-progress-bar-2.12.0.tgz: package/lib/ProgressBarCircle/index.js <==
import cx from 'classnames';
import PropTypes from 'prop-types';
import { LINE_CAPS, SIZES, STATUS } from '../settings.js';
import Circle from './Circle/index.js';
import Indicator from './Indicator.js';
import { BASE_CLASS_NAME, SIZE_TO_WIDTH_LINE_MAP, STROKE_SIZE_MAP } from './settings.js';
import { jsx as _jsx } from "react/jsx-runtime";
import { jsxs as _jsxs } from "react/jsx-runtime";
var ProgressBarCircle = function ProgressBarCircle(_ref) {
  var percentage = _ref.percentage,
    status = _ref.status,
    errorIcon = _ref.errorIcon,
    size = _ref.size,
    isAnimatedOnChange = _ref.isAnimatedOnChange,
    hideIndicator = _ref.hideIndicator,
    children = _ref.children,
    mainStrokeSize = _ref.mainStrokeSize,
    progressStrokeSize = _ref.progressStrokeSize,
    strokeLineCap = _ref.strokeLineCap;
  var mainStrokeWidth = STROKE_SIZE_MAP[mainStrokeSize] || SIZE_TO_WIDTH_LINE_MAP[size];
  var progressStrokeWidth = STROKE_SIZE_MAP[progressStrokeSize] || SIZE_TO_WIDTH_LINE_MAP[size];
  return /*#__PURE__*/_jsxs("div", {
    className: cx(BASE_CLASS_NAME, BASE_CLASS_NAME + "--" + size, BASE_CLASS_NAME + "--" + status),
    children: [/*#__PURE__*/_jsx(Circle, {
      baseClassName: BASE_CLASS_NAME,
      mainStrokeWidth: mainStrokeWidth,
      modifier: status,
      percentage: status === STATUS.PROGRESS ? percentage : 0,
      progressStrokeWidth: progressStrokeWidth,
      size: size,
      strokeLineCap: strokeLineCap,
      withAnimation: isAnimatedOnChange
    }), !hideIndicator && /*#__PURE__*/_jsx(Indicator, {
      percentage: percentage,
      size: size,
      status: status,
      errorIcon: errorIcon,
      children: children
    })]
  });
};
ProgressBarCircle.displayName = 'ProgressBarCircle';
ProgressBarCircle.defaultProps = {
  isAnimatedOnChange: false,
  strokeLineCap: LINE_CAPS.SQUARE,
  status: STATUS.PROGRESS,
  hideIndicator: false,
  size: SIZES.LARGE
};
export default ProgressBarCircle;

==> react-atom-progress-bar-2.13.0.tgz: package/lib/ProgressBarCircle/index.js <==
import cx from 'classnames';
import PropTypes from 'prop-types';
import { LINE_CAPS, SIZES, STATUS } from '../settings.js';
import Circle from './Circle/index.js';
import Indicator from './Indicator.js';
import { BASE_CLASS_NAME, SIZE_TO_WIDTH_LINE_MAP, STROKE_SIZE_MAP } from './settings.js';
import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
var ProgressBarCircle = function ProgressBarCircle(_ref) {
  var percentage = _ref.percentage,
    _ref$status = _ref.status,
    status = _ref$status === void 0 ? STATUS.PROGRESS : _ref$status,
    errorIcon = _ref.errorIcon,
    _ref$size = _ref.size,
    size = _ref$size === void 0 ? SIZES.LARGE : _ref$size,
    _ref$isAnimatedOnChan = _ref.isAnimatedOnChange,
    isAnimatedOnChange = _ref$isAnimatedOnChan === void 0 ? false : _ref$isAnimatedOnChan,
    _ref$hideIndicator = _ref.hideIndicator,
    hideIndicator = _ref$hideIndicator === void 0 ? false : _ref$hideIndicator,
    children = _ref.children,
    mainStrokeSize = _ref.mainStrokeSize,
    progressStrokeSize = _ref.progressStrokeSize,
    _ref$strokeLineCap = _ref.strokeLineCap,
    strokeLineCap = _ref$strokeLineCap === void 0 ? LINE_CAPS.SQUARE : _ref$strokeLineCap;
  var mainStrokeWidth = STROKE_SIZE_MAP[mainStrokeSize] || SIZE_TO_WIDTH_LINE_MAP[size];
  var progressStrokeWidth = STROKE_SIZE_MAP[progressStrokeSize] || SIZE_TO_WIDTH_LINE_MAP[size];
  return /*#__PURE__*/_jsxs("div", {
    className: cx(BASE_CLASS_NAME, BASE_CLASS_NAME + "--" + size, BASE_CLASS_NAME + "--" + status),
    children: [/*#__PURE__*/_jsx(Circle, {
      baseClassName: BASE_CLASS_NAME,
      mainStrokeWidth: mainStrokeWidth,
      modifier: status,
      percentage: status === STATUS.PROGRESS ? percentage : 0,
      progressStrokeWidth: progressStrokeWidth,
      size: size,
      strokeLineCap: strokeLineCap,
      withAnimation: isAnimatedOnChange
    }), !hideIndicator && /*#__PURE__*/_jsx(Indicator, {
      percentage: percentage,
      size: size,
      status: status,
      errorIcon: errorIcon,
      children: children
    })]
  });
};
ProgressBarCircle.displayName = 'ProgressBarCircle';
export default ProgressBarCircle;
